@@ -16,8 +16,8 @@ from PIL import Image as PILImage
 from PIL import ImageDraw as PILImageDraw
 from PIL import ImageFilter, ImageGrab, ImageWin, ImageFont, ImageEnhance
 from PIL.Image import Transpose, Transform, Resampling, Dither, Palette, Quantize, SupportsArrayInterface
-from PIL.ImageDraw import _Ink
 
+_Ink = Union[float, Tuple[int, ...], str]
 Array2 = np.ndarray
 Coord4 = Union[Tuple[float, float, float, float], Sequence[float]]
 
@@ -54,6 +54,8 @@ class Image:
         else:
             raise TypeError(f"Unsupported source type: {type(source)}")
 
+        self._publisher = None
+
         self.boxes = [],
         '''
         self.boxes = [
@@ -157,6 +159,9 @@ class Image:
             return cv2.cvtColor(arr, cv2.COLOR_RGB2BGR)
         raise ValueError("Mode must be 'RGB' or 'BGR'")
 
+    def pil(self):
+        return self.image
+
     def to_xyxy(
             self,
             xyxy: Optional[Union[Tuple[float, float, float, float], List[float], np.ndarray]] = None,
@@ -324,6 +329,18 @@ class Image:
         self.image = self.image.rotate(angle, resample, expand, center, translate, fillcolor)
         return self
 
+    def shift(self, dx: int, dy: int) -> Self:
+        """
+        Shift the image by (dx, dy) pixels.
+        Positive dx -> shift right
+        Positive dy -> shift down
+        """
+        # Affine transform matrix for translation
+        matrix = (1, 0, dx,  # x' = x + dx
+                  0, 1, dy)  # y' = y + dy
+        self.image = self.image.transform(self.image.size, PILImage.AFFINE, matrix)
+        return self
+
     def transpose(self, method: PILImage.Transpose) -> Self:
         self.image = self.image.transpose(method)
         return self
@@ -343,14 +360,14 @@ class Image:
             if not isinstance(box, Box):
                 return Image(self.image.crop(box))
         else:
-            box = Box(self.size, xyxy=xyxy, xywh=xywh, xyxyn=xyxyn, xywhn=xywhn, points=points, pointsn=pointsn)
+            box = Box(size=self.size, xyxy=xyxy, xywh=xywh, xyxyn=xyxyn, xywhn=xywhn, points=points, pointsn=pointsn)
         box.move(*shift, normalized=False)
         if box.type == 'polygon':
             img = self.numpy()
             mask = np.zeros(img.shape[:2], dtype=np.uint8)
-            cv2.fillPoly(mask, [box.points_int32()], 255)
+            cv2.fillPoly(mask, [box.points.astype(np.int32)], 255)
             masked = cv2.bitwise_and(img, img, mask=mask)
-            x, y, w, h = cv2.boundingRect(box.points_int32())
+            x, y, w, h = cv2.boundingRect(box.points.astype(np.int32))
             cropped = masked[y:y + h, x:x + w]
             return Image(cropped)
         elif box.type == 'box':
@@ -604,6 +621,13 @@ class Image:
         self.image.show(title=title)
         return self
 
+    def publish(self, winname: str = "window", **kwargs):
+        if self._publisher is None:
+            from hexss.frame_publisher import FramePublisher
+            self._publisher: FramePublisher = FramePublisher(open_browser=True, jpeg_quality=100, **kwargs)
+
+        self._publisher.show(winname, self.pil())
+
     def detect(self, model):
         self.detections = model.detect(self)
         return self.detections
@@ -716,6 +740,8 @@ class ImageDraw:
             xywhn: tuple[float, float, float, float] | list[float] | np.ndarray | None = None,
     ) -> Self:
         if isinstance(xy, Box):
+            if not xy._size:
+                xy.set_size(self.im.size)
             xy = xy.xyxy.tolist()
         if xy is None:
             xy = self.im.to_xyxy(xyxy, xywh, xyxyn, xywhn)
